@@ -32,7 +32,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#define MP_SIZE      150     /* Size of the multiple precision values. */
+#define MP_SIZE      1000     /* Size of the multiple precision values. */
 
 #define FCLOSE       (void) fclose     /* To make lint happy. */
 #define FPRINTF      (void) fprintf
@@ -148,7 +148,7 @@ enum trig_func {SIN=0, COS=1, TAN=2};
 #define KEY_OR    s_buttons[27]             /* | */
 #define KEY_AND   s_buttons[28]             /* & */
 #define KEY_NOT   s_buttons[29]             /* ~ */
-#define KEY_XOR   s_buttons[30]             /* ^ */
+#define KEY_XOR   s_buttons[30]             /* x */
 #define KEY_XNOR  s_buttons[31]             /* n */
 
 #define BCOLS          4      /* No of columns of Basic Mode buttons. */
@@ -176,7 +176,7 @@ enum trig_func {SIN=0, COS=1, TAN=2};
 #endif /*lint*/
 #endif /*LINT_CAST*/
 
-#define MAX_DIGITS     40         /* Maximum displayable number of digits. */
+#define MAX_DIGITS     200         /* Maximum displayable number of digits. */
 #define MAX_LOCALIZED  (MAX_DIGITS * (1 + MB_LEN_MAX) + MB_LEN_MAX)
 
 /* Maximum number of various graphics pieces. */
@@ -187,7 +187,7 @@ enum trig_func {SIN=0, COS=1, TAN=2};
 #define MAXLINE        512        /* Length of character strings. */
 #endif /*MAXLINE*/
 
-#define MAXACC         30    /* Max. number of digits after numeric point. */
+#define MAXACC         99     /* Max. number of digits after numeric point. */
 #define MAXBASES       4          /* Maximum number of numeric bases. */
 #define MAXCONFUN      10         /* Maximum number of constants/functions. */
 #define MAXDISPMODES   3          /* Maximum number of display modes. */
@@ -254,7 +254,11 @@ enum button_flags {
     expnum       = (1 << 13),  /* Exponential number */
     postfixop    = (1 << 14),  /* Unary postfix operation */
     prefixop     = (1 << 15),  /* Unary prefix operation */
-    dpoint       = (1 << 16)   /* Decimal point */
+    dpoint       = (1 << 16),  /* Decimal point */
+    pending      = (1 << 17),  /* Is a pending button */
+    hex          = (1 << 18),  /* Is a hex button A..F */
+    oct_set      = (1 << 19),  /* Is a oct button 0..7 */
+    bin_set      = (1 << 20)   /* Is a bin button 0..1 */
 };
 
 enum shiftd {
@@ -354,6 +358,8 @@ struct calcVars {                      /* Calctool variables and options. */
     int doing_mi;      /* Set if adjusting the "show zeroes" menu item. */
     int down;          /* Indicates is a mouse button is down. */
     int error;         /* Indicates some kind of display error. */
+    int ghost_zero;    /* Flag to indicate display with "0", actually 
+                           having empty content. */
     int math_error;    /* Math error (used in expression mode) */
     int hyperbolic;    /* If set, trig functions will be hyperbolic. */
     int iconic;        /* Set if window is currently iconic. */
@@ -544,4 +550,10 @@ void mpstr(int *, int *);
 void mpsub(int *, int *, int *);
 void mptanh(int *, int *);
 
+void make_exp(char *number, int t[MP_SIZE]);
+void exp_replace(char *text);
+void insert_to_cursor(char *text);
+void get_expr_from_display();
+void delete_from_cursor();
+
 #endif /*CALCTOOL_H*/
